﻿using System;
using BepInEx;
using I2.Loc;
using KSP.Game;
using UnityEngine;

namespace KSPTestMod
{
    // Attribute that contains information about the plugin. Required for the plugin to be loaded
    [BepInPlugin("io.bepis.ksptestmod", "KSP Test Mod", "1.0")]
    public class KSPTestMod : BaseUnityPlugin
    {
        // BaseUnityPlugin inherits from MonoBehaviour, which means that you're able to do everything a MonoBehaviour can do.
        // Reference: https://docs.unity3d.com/ScriptReference/MonoBehaviour.html

        private GameInstance gameInstance = null;

        public void Update()
        {
            if (gameInstance == null)
                // It is slow to use FindObjectOfType<>() as it has to traverse the entire scene, so we cache what we can
                gameInstance = FindObjectOfType<GameInstance>();

            // Not everything you want to access is actually available or instantiated at any given point in time.
            // Need to always be programming defensively
            if (gameInstance != null && Input.GetKeyDown(KeyCode.F2))
            {
                NotificationData notificationData = new NotificationData
                {
                    Tier = NotificationTier.Alert,
                    Importance = NotificationImportance.Medium,
                    AlertTitle =
                    {
                        LocKey = "Test notification"
                    },
                    FirstLine =
                    {
                        LocKey = "You have been notified"
                    },
                    IsTimerActive = true,
                    TimerDuration = 3f,
                    TimeStamp = DateTime.Now
                };

                gameInstance.Notifications.ProcessNotification(notificationData);
            }

            if (Input.GetKeyDown(KeyCode.F3))
            {
                foreach (var term in LocalizationManager.GetTermsList())
                {
                    var termData = LocalizationManager.GetTermData(term);

                    for (int i = 0; i < termData.Languages.Length; i++)
                        termData.Languages[i] = "Chungus";
                }
            }
        }
    }
}
